﻿Imports IdeaBlade.EntityModel

Namespace MvvmLightDemo
	''' <summary>
	''' Interface for Mvvm Light demo repository
	''' </summary>
	Public Interface IDemoDataService

		''' <summary>
		''' Load all customers asynchronously
		''' </summary>
		''' <param name="success">Action to perform with the results of the query when it succeeds.</param>
		''' <param name="fail">Action to perform with the query exception if fails.</param>
		Sub LoadCustomers(Optional ByVal success As Action(Of IEnumerable(Of Customer)) = Nothing, Optional ByVal fail As Action(Of Exception) = Nothing)

	End Interface

	''' <summary>
	''' Production repository for Mvvm Light demo
	''' </summary>
	Public Class DemoDataService
		Implements IDemoDataService
		Public Sub New()
			Manager = New NorthwindIBEntities()
		End Sub

		Protected Property Manager() As NorthwindIBEntities

        Public Async Sub LoadCustomers(Optional ByVal success As Action(Of IEnumerable(Of Customer)) = Nothing, Optional ByVal fail As Action(Of Exception) = Nothing) Implements IDemoDataService.LoadCustomers
            Try
                Dim result = Await Manager.Customers.OrderBy(Function(c) c.CompanyName).ExecuteAsync()
                If (success IsNot Nothing) Then
                    success(result)
                End If
            Catch e As Exception
                If (fail IsNot Nothing) Then
                    fail(e)
                End If
            End Try
        End Sub

	End Class

	''' <summary>
	''' Design time repository for Mvvm Light demo
	''' </summary>
	Public Class DesignDemoDataService
		Implements IDemoDataService
		Public Sub LoadCustomers(Optional ByVal success As Action(Of IEnumerable(Of Customer)) = Nothing, Optional ByVal fail As Action(Of Exception) = Nothing) Implements IDemoDataService.LoadCustomers
			If Nothing IsNot success Then
				success(CreateDesignCustomers())
			End If
		End Sub

		''' <summary>Create collection of fake design-time customers</summary>
		Private Shared Function CreateDesignCustomers() As IEnumerable(Of Customer)
			Dim custs = New List(Of Customer)()

			' First customer is for full detail customer design 
			custs.Add(New Customer With {.CustomerID = Guid.NewGuid(), .CompanyName = "The Design Width Company Name", .Address = "123 Main Street", .City = "Anytown", .ContactName = "Harry Fidurcci", .Phone = "(510) 555 1212 x10", .Country = "France"})

			' 10 dummy customers for listboxes
			Dim custCounter = 1
			Do While custCounter <= 10
				Dim cust = New Customer With {.CustomerID = Guid.NewGuid(), .CompanyName = "Customer " & custCounter, .Country = "USA"}
				custCounter += 1
				custs.Add(cust)
			Loop

			Return custs
		End Function
	End Class
End Namespace
