Imports System.Collections.ObjectModel
Imports GalaSoft.MvvmLight

Namespace MvvmLightDemo.ViewModel
	''' <summary>
	''' This class contains properties that the main View can data bind to.
	''' <para>
	''' Use the <strong>mvvminpc</strong> snippet to add bindable properties to this ViewModel.
	''' </para>
	''' <para>
	''' You can also use Blend to data bind with the tool's support.
	''' </para>
	''' <para>
	''' See http://www.galasoft.ch/mvvm
	''' </para>
	''' </summary>
	Public Class MainViewModel
		Inherits ViewModelBase

		Private _dataService As IDemoDataService

		''' <summary>
		''' Initializes a new instance of the MainViewModel class.
		''' </summary>
		Public Sub New(ByVal dataService As IDemoDataService)
			_dataService = dataService
			Customers = New ObservableCollection(Of Customer)()
			Message = "... Loading ..."

			_dataService.LoadCustomers(AddressOf CustomersLoaded, AddressOf CustomerLoadFailed)

		End Sub

		Private Sub CustomersLoaded(ByVal customers As IEnumerable(Of Customer))
			For Each customer In customers
				Me.Customers.Add(customer)
			Next customer
			CurrentCustomer = customers.FirstOrDefault()
			Message = "Customers loaded."
		End Sub

		Private Sub CustomerLoadFailed(ByVal except As Exception)
			Message = "Customer Load Failed: " & except.Message
		End Sub

		Private privateCustomers As ObservableCollection(Of Customer)
		Public Property Customers() As ObservableCollection(Of Customer)
			Get
				Return privateCustomers
			End Get
			Private Set(ByVal value As ObservableCollection(Of Customer))
				privateCustomers = value
			End Set
		End Property

		Private _message As String
		Public Property Message() As String
			Get
				Return _message
			End Get
			Set(ByVal value As String)
				_message = value
				RaisePropertyChanged("Message")
			End Set
		End Property


		Private _currentCustomer As Customer
		Public Property CurrentCustomer() As Customer
			Get
				Return _currentCustomer
			End Get
			Set(ByVal value As Customer)
				_currentCustomer = value
				RaisePropertyChanged("CurrentCustomer")
			End Set
		End Property

	End Class
End Namespace